<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>LayerCompatibility</name>
    <message>
        <location filename="../LayerCompatibility.js" line="+30"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Compatibility</source>
        <translation>Compatibilità</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Layer 0</source>
        <translation>Layer 0</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Layer 0 behaves like a regular layer (QCAD)</source>
        <translation>Layer 0 si comporta come un livello normale</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Layer 0 behaves differently (best compatibility)</source>
        <translation>Layer 0 comporta diversamente (migliore compatibilità)</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
        <translation>Entità in blocchi sul layer 0 assumere attributi e visibilità del riferimento di blocco.</translation>
    </message>
    <message>
        <source>Entities in blocks on layer 0 take on attributes of block reference (compatibility)</source>
        <translation type="vanished">Entità in blocchi sul layer 0 assumere attributi del riferimento di blocco (compatibilità)</translation>
    </message>
</context>
</TS>
